==> suir-component-mapper-3.11.0.tgz: package/esm/date-picker/date-picker.js <==
import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
import React from 'react';
import PropTypes from 'prop-types';
import FormFieldGrid from '../form-field-grid/form-field-grid';
import { validationError, validationWarning } from '../helpers/helpers';
import useFieldApi from "@data-driven-forms/react-form-renderer/use-field-api";
import FormField from '../form-field/form-field';

var DatePicker = function DatePicker(props) {
  var _useFieldApi = useFieldApi(props),
      input = _useFieldApi.input,
      isReadOnly = _useFieldApi.isReadOnly,
      isDisabled = _useFieldApi.isDisabled,
      placeholder = _useFieldApi.placeholder,
      isRequired = _useFieldApi.isRequired,
      label = _useFieldApi.label,
      helperText = _useFieldApi.helperText,
      validateOnMount = _useFieldApi.validateOnMount,
      meta = _useFieldApi.meta,
      FormFieldGridProps = _useFieldApi.FormFieldGridProps,
      HelperTextProps = _useFieldApi.HelperTextProps,
      rest = _objectWithoutProperties(_useFieldApi, ["input", "isReadOnly", "isDisabled", "placeholder", "isRequired", "label", "helperText", "validateOnMount", "meta", "FormFieldGridProps", "HelperTextProps"]);

  var invalid = validationError(meta, validateOnMount);
  return /*#__PURE__*/React.createElement(FormFieldGrid, _extends({
    helperText: validationWarning(meta, validateOnMount) || helperText,
    HelperTextProps: HelperTextProps
  }, FormFieldGridProps), /*#__PURE__*/React.createElement(FormField, _extends({
    label: label
  }, input, {
    type: "date",
    required: isRequired,
    error: invalid && {
      content: meta.error || meta.submitError
    }
  }, rest, {
    control: function control(props) {
      return /*#__PURE__*/React.createElement("input", _extends({}, props, {
        readOnly: isReadOnly,
        disabled: isDisabled,
        placeholder: placeholder
      }));
    }
  })));
};

DatePicker.propTypes = {
  isReadOnly: PropTypes.bool,
  isDisabled: PropTypes.bool,
  placeholder: PropTypes.node,
  isRequired: PropTypes.bool,
  label: PropTypes.node,
  helperText: PropTypes.node,
  validateOnMount: PropTypes.bool,
  description: PropTypes.node,

  /** Sub components customization API */
  FormFieldGridProps: PropTypes.object,
  HelperTextProps: PropTypes.object
};
DatePicker.defaultProps = {
  FormFieldGridProps: {},
  HelperTextProps: {}
};
export default DatePicker;

==> suir-component-mapper-3.22.0.tgz: package/esm/date-picker/date-picker.js <==
import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
var _excluded = ["input", "isReadOnly", "isDisabled", "placeholder", "isRequired", "label", "helperText", "validateOnMount", "meta", "FormFieldGridProps", "HelperTextProps"];
import React from 'react';
import PropTypes from 'prop-types';
import FormFieldGrid from '../form-field-grid/form-field-grid';
import { validationError, validationWarning } from '../helpers/helpers';
import useFieldApi from "@data-driven-forms/react-form-renderer/use-field-api";
import FormField from '../form-field/form-field';

var DatePicker = function DatePicker(props) {
  var _useFieldApi = useFieldApi(props),
      input = _useFieldApi.input,
      isReadOnly = _useFieldApi.isReadOnly,
      isDisabled = _useFieldApi.isDisabled,
      placeholder = _useFieldApi.placeholder,
      isRequired = _useFieldApi.isRequired,
      label = _useFieldApi.label,
      helperText = _useFieldApi.helperText,
      validateOnMount = _useFieldApi.validateOnMount,
      meta = _useFieldApi.meta,
      FormFieldGridProps = _useFieldApi.FormFieldGridProps,
      HelperTextProps = _useFieldApi.HelperTextProps,
      rest = _objectWithoutProperties(_useFieldApi, _excluded);

  var invalid = validationError(meta, validateOnMount);
  return /*#__PURE__*/React.createElement(FormFieldGrid, _extends({
    helperText: validationWarning(meta, validateOnMount) || helperText,
    HelperTextProps: HelperTextProps
  }, FormFieldGridProps), /*#__PURE__*/React.createElement(FormField, _extends({
    label: label
  }, input, {
    type: "date",
    required: isRequired,
    error: invalid && {
      content: meta.error || meta.submitError
    }
  }, rest, {
    control: function control(props) {
      return /*#__PURE__*/React.createElement("input", _extends({}, props, {
        readOnly: isReadOnly,
        disabled: isDisabled,
        placeholder: placeholder
      }));
    }
  })));
};

DatePicker.propTypes = {
  isReadOnly: PropTypes.bool,
  isDisabled: PropTypes.bool,
  placeholder: PropTypes.node,
  isRequired: PropTypes.bool,
  label: PropTypes.node,
  helperText: PropTypes.node,
  validateOnMount: PropTypes.bool,
  description: PropTypes.node,

  /** Sub components customization API */
  FormFieldGridProps: PropTypes.object,
  HelperTextProps: PropTypes.object
};
DatePicker.defaultProps = {
  FormFieldGridProps: {},
  HelperTextProps: {}
};
export default DatePicker;
